package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltProjectMonthCosts;
import com.bonus.material.settlement.service.ISltProjectMonthCostsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 月结算费用Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "月结算费用接口")
@RestController
@RequestMapping("/slt_project_month_costs")
public class SltProjectMonthCostsController extends BaseController {
    @Autowired
    private ISltProjectMonthCostsService sltProjectMonthCostsService;

    /**
     * 查询月结算费用列表
     */
    @ApiOperation(value = "查询月结算费用列表")
    @RequiresPermissions("settlement:costs:list")
    @GetMapping("/list")
    public TableDataInfo list(SltProjectMonthCosts sltProjectMonthCosts) {
        startPage();
        List<SltProjectMonthCosts> list = sltProjectMonthCostsService.selectSltProjectMonthCostsList(sltProjectMonthCosts);
        return getDataTable(list);
    }

    /**
     * 导出月结算费用列表
     */
    @ApiOperation(value = "导出月结算费用列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:costs:export")
    @SysLog(title = "月结算费用", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出月结算费用")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltProjectMonthCosts sltProjectMonthCosts) {
        List<SltProjectMonthCosts> list = sltProjectMonthCostsService.selectSltProjectMonthCostsList(sltProjectMonthCosts);
        ExcelUtil<SltProjectMonthCosts> util = new ExcelUtil<SltProjectMonthCosts>(SltProjectMonthCosts.class);
        util.exportExcel(response, list, "月结算费用数据");
    }

    /**
     * 获取月结算费用详细信息
     */
    @ApiOperation(value = "获取月结算费用详细信息")
    @RequiresPermissions("settlement:costs:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltProjectMonthCostsService.selectSltProjectMonthCostsById(id));
    }

    /**
     * 新增月结算费用
     */
    @ApiOperation(value = "新增月结算费用")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:costs:add")
    @SysLog(title = "月结算费用", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增月结算费用")
    @PostMapping
    public AjaxResult add(@RequestBody SltProjectMonthCosts sltProjectMonthCosts) {
        try {
            return toAjax(sltProjectMonthCostsService.insertSltProjectMonthCosts(sltProjectMonthCosts));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改月结算费用
     */
    @ApiOperation(value = "修改月结算费用")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:costs:edit")
    @SysLog(title = "月结算费用", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改月结算费用")
    @PutMapping
    public AjaxResult edit(@RequestBody SltProjectMonthCosts sltProjectMonthCosts) {
        try {
            return toAjax(sltProjectMonthCostsService.updateSltProjectMonthCosts(sltProjectMonthCosts));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除月结算费用
     */
    @ApiOperation(value = "删除月结算费用")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:costs:remove")
    @SysLog(title = "月结算费用", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除月结算费用")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltProjectMonthCostsService.deleteSltProjectMonthCostsByIds(ids));
    }
}
